@@ -4,6 +4,7 @@
 #include <glib.h>
 #include <gdk/gdk.h>
 
+#include "libgnome-panel/gp-applet-private.h"
 #include "panel-widget.h"
 
 G_BEGIN_DECLS
@@ -20,11 +21,18 @@ typedef struct {
   char      *id;
 } AppletInfo;
 
+typedef void (* PanelAppletForeachFunc) (AppletInfo *info,
+                                         gpointer    user_data);
+
 AppletInfo *panel_applet_register           (GtkWidget   *applet,
                                              PanelWidget *panel,
                                              const char  *id,
                                              GSettings   *settings);
 
+PanelWidget *panel_applet_get_panel_widget  (AppletInfo  *info);
+
+GpApplet    *panel_applet_get_applet        (AppletInfo  *info);
+
 const char *panel_applet_get_id             (AppletInfo  *info);
 
 const char *panel_applet_get_toplevel_id    (AppletInfo  *info);
@@ -33,6 +41,10 @@ gboolean    panel_applet_activate_main_menu (guint32      activate_time);
 
 GSList     *panel_applet_list_applets       (void);
 
+void        panel_applet_foreach            (PanelWidget            *panel,
+                                             PanelAppletForeachFunc  func,
+                                             gpointer                user_data);
+
 void        panel_applet_clean              (AppletInfo  *info);
 
 void        panel_applet_save_position      (AppletInfo  *applet_info,
