@@ -43,6 +43,12 @@ typedef enum { /*< flags=0 >*/
 #define PANEL_HORIZONTAL_MASK (PANEL_ORIENTATION_TOP | PANEL_ORIENTATION_BOTTOM)
 #define PANEL_VERTICAL_MASK (PANEL_ORIENTATION_LEFT | PANEL_ORIENTATION_RIGHT)
 
+typedef enum {
+	PANEL_ALIGNMENT_START  = 0,
+	PANEL_ALIGNMENT_CENTER = 1,
+	PANEL_ALIGNMENT_END    = 2
+} PanelAlignment;
+
 typedef enum {
 	PANEL_ANIMATION_SLOW   = 0,
 	PANEL_ANIMATION_MEDIUM = 1,
