@@ -41,6 +41,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdkx.h>
 #include <gmenu-tree.h>
+#include <libgnome-desktop/gnome-systemd.h>
 
 #include <libpanel-util/panel-error.h>
 #include <libpanel-util/panel-glib.h>
@@ -502,6 +503,14 @@ panel_run_dialog_launch_command (PanelRunDialog *dialog,
 		g_error_free (error);
 	} else {
 		g_child_watch_add (pid, dummy_child_watch, NULL);
+
+		gnome_start_systemd_scope (locale_command,
+					   pid,
+					   NULL,
+					   NULL,
+					   NULL,
+					   NULL,
+					   NULL);
 	}
 
 	g_strfreev (argv);
