@@ -33,10 +33,6 @@ G_BEGIN_DECLS
 gboolean clock_locale_supports_am_pm (void);
 GDesktopClockFormat clock_locale_format (void);
 
-void clock_utils_display_help (GtkWidget  *widget,
-			       const char *doc_id,
-			       const char *link_id);
-
 G_END_DECLS
 
 #endif /* __CLOCK_UTILS_H__ */
